==> cli-cm-bulk-publish-1.7.1.tgz: package/src/commands/cm/stacks/publish-revert.js <==
const { Command } = require('@contentstack/cli-command');
const { cliux, printFlagDeprecation, flags } = require('@contentstack/cli-utilities');

const store = require('../../../util/store.js');
const { start } = require('../../../producer/revert');
const { prettyPrint, formatError } = require('../../../util');

let config;
const configKey = 'revert';

class RevertCommand extends Command {
  async run() {
    const { flags: revertFlags } = await this.parse(RevertCommand);
    revertFlags.retryFailed = revertFlags['retry-failed'] || revertFlags.retryFailed;
    revertFlags.logFile = revertFlags['log-file'] || revertFlags.logFile;
    delete revertFlags['retry-failed'];
    delete revertFlags['log-file'];

    let updatedFlags;
    try {
      updatedFlags = revertFlags.config ? store.updateMissing(configKey, revertFlags) : revertFlags;
    } catch (error) {
      this.error(error.message, { exit: 2 });
    }
    if (this.validate(updatedFlags)) {
      if (await this.confirmFlags(updatedFlags)) {
        try {
          await start(updatedFlags, config);
        } catch (error) {
          const message = formatError(error);
          this.error(message, { exit: 2 });
        }
      } else {
        this.exit(0);
      }
    }
  }

  validate({ retryFailed, logFile }) {
    let missing = [];
    if (retryFailed) {
      return true;
    }

    if (!logFile) {
      missing.push('log-file');
    }

    if (missing.length > 0) {
      this.error(
        `${missing.join(', ')} is required for processing this command. Please check --help for more details`,
        { exit: 2 },
      );
    } else {
      return true;
    }
  }

  async confirmFlags(data) {
    prettyPrint(data);
    if (data.yes) {
      return true;
    }
    return cliux.confirm('Do you want to continue with this configuration ? [yes or no]');
  }
}

RevertCommand.description = `Revert publish operations by using a log file
The revert command is used to revert all publish operations performed using bulk-publish script.
A log file name is required to execute revert command
`;

RevertCommand.flags = {
  'retry-failed': flags.string({ description: '(optional)  Use this option to retry publishing the failed entries from the logfile. Specify the name of the logfile that lists failed publish calls. If this option is used, it will override all other flags.' }),
  'log-file': flags.string({ description: 'Path of the success logfile of a particular publish action.' }),

  //To be deprecated
  retryFailed: flags.string({
    char: 'r',
    description: '(optional)  Use this option to retry publishing the failed entries from the logfile. Specify the name of the logfile that lists failed publish calls. If this option is used, it will override all other flags.',
    hidden: true,
    parse: printFlagDeprecation(['-r', '--retryFailed'], ['--retry-failed']),
  }),
  logFile: flags.string({
    char: 'l',
    description: 'Path of the success logfile of a particular publish action.',
    hidden: true,
    parse: printFlagDeprecation(['-l', '--logFile'], ['--log-file']),
  }),
};

RevertCommand.examples = [
  'Using --log-file',
  'cm:bulk-publish:revert --log-file [LOG FILE NAME]',
  '',
  'Using --retry-failed',
  'cm:bulk-publish:revert --retry-failed [LOG FILE NAME]',
];

RevertCommand.aliases = ['cm:bulk-publish:revert'];

module.exports = RevertCommand;

==> cli-cm-bulk-publish-1.8.0.tgz: package/src/commands/cm/stacks/publish-revert.js <==
const { Command } = require('@contentstack/cli-command');
const { cliux, printFlagDeprecation, flags } = require('@contentstack/cli-utilities');

const store = require('../../../util/store.js');
const { start } = require('../../../producer/revert');
const { prettyPrint, formatError } = require('../../../util');

let config;
const configKey = 'revert';

class RevertCommand extends Command {
  async run() {
    const { flags: revertFlags } = await this.parse(RevertCommand);
    revertFlags.retryFailed = revertFlags['retry-failed'] || revertFlags.retryFailed;
    revertFlags.logFile = revertFlags['log-file'] || revertFlags.logFile;
    delete revertFlags['retry-failed'];
    delete revertFlags['log-file'];

    let updatedFlags;
    try {
      updatedFlags = revertFlags.config ? store.updateMissing(configKey, revertFlags) : revertFlags;
    } catch (error) {
      this.error(error.message, { exit: 2 });
    }
    if (this.validate(updatedFlags)) {
      if (await this.confirmFlags(updatedFlags)) {
        try {
          await start(updatedFlags, config);
        } catch (error) {
          const message = formatError(error);
          this.error(message, { exit: 2 });
        }
      } else {
        this.exit(0);
      }
    }
  }

  validate({ retryFailed, logFile }) {
    let missing = [];
    if (retryFailed) {
      return true;
    }

    if (!logFile) {
      missing.push('log-file');
    }

    if (missing.length > 0) {
      this.error(
        `${missing.join(', ')} is required for processing this command. Please check --help for more details`,
        { exit: 2 },
      );
    } else {
      return true;
    }
  }

  async confirmFlags(data) {
    prettyPrint(data);
    if (data.yes) {
      return true;
    }
    return await cliux.confirm('Do you want to continue with this configuration ? [yes or no]');
  }
}

RevertCommand.description = `Revert publish operations by using a log file
The revert command is used to revert all publish operations performed using bulk-publish script.
A log file name is required to execute revert command
`;

RevertCommand.flags = {
  'retry-failed': flags.string({
    description:
      '(optional)  Use this option to retry publishing the failed entries from the logfile. Specify the name of the logfile that lists failed publish calls. If this option is used, it will override all other flags.',
  }),
  'log-file': flags.string({ description: 'Path of the success logfile of a particular publish action.' }),

  //To be deprecated
  retryFailed: flags.string({
    char: 'r',
    description:
      '(optional)  Use this option to retry publishing the failed entries from the logfile. Specify the name of the logfile that lists failed publish calls. If this option is used, it will override all other flags.',
    hidden: true,
    parse: printFlagDeprecation(['-r', '--retryFailed'], ['--retry-failed']),
  }),
  logFile: flags.string({
    char: 'l',
    description: 'Path of the success logfile of a particular publish action.',
    hidden: true,
    parse: printFlagDeprecation(['-l', '--logFile'], ['--log-file']),
  }),
};

RevertCommand.examples = [
  'Using --log-file',
  'cm:bulk-publish:revert --log-file [LOG FILE NAME]',
  '',
  'Using --retry-failed',
  'cm:bulk-publish:revert --retry-failed [LOG FILE NAME]',
];

RevertCommand.aliases = ['cm:bulk-publish:revert'];

module.exports = RevertCommand;
